camelot.camelot.view.proxy.collection_proxy.EmptyRowData

Package camelot :: Package camelot :: Package view :: Package proxy :: Module collection_proxy :: Class EmptyRowData |
[hide private]
[frames] | no frames]

# Class EmptyRowData

source code

Instance Methods | [hide private]
__getitem__(self, column) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`